<?php

/** 
 * Send a POST requst using cURL 
 * @param string $url to request 
 * @param array $post values to send 
 * @param array $options for cURL 
 * @return string 
 */
function curl_post($url, array $post = NULL, array $options = array(), $redirects = 0)
{
  $defaults = array(
    CURLOPT_POST => 1,
    CURLOPT_HEADER => 1,
    CURLOPT_URL => $url,
    CURLOPT_FRESH_CONNECT => 1,
    CURLOPT_RETURNTRANSFER => 1,
    CURLOPT_FORBID_REUSE => 1,
    CURLOPT_TIMEOUT => 4,
    CURLOPT_POSTFIELDS => http_build_query($post),
    CURLOPT_SSL_VERIFYHOST => false,
    CURLOPT_SSL_VERIFYPEER => false,
    CURLOPT_FOLLOWLOCATION => false,
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_MAXREDIRS => 5
  );

  $ch = curl_init();
  curl_setopt_array($ch, ($options + $defaults));
  $result = curl_exec($ch);
  $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
  if ($http_code === 301 || $http_code === 302) {
    $header = explode("\r\n\r\n", $result, 2)[0];
    $matches = array();
    preg_match('/(Location:|URI:)(.*?)\n/', $header, $matches);
    $url = trim(array_pop($matches));
    $url_parsed = parse_url($url);
    if (isset($url_parsed)) {
      return curl_post($url, $post, $options, $redirects + 1);
    }
  } else {
    curl_close($ch);
    list(, $body) = explode("\r\n\r\n", $result, 2);
    return $body;
  }
}


function AuthentifyWithMaintKey()
{
  $ombukey = trim(file_get_contents("/etc/ombutel/ombutel-maint.conf"));
  $data = array("key" => $ombukey);
  $retour = curl_post("http://localhost/api/authenticate", $data);
  if ($retour === FALSE) {
    return "";
  }
  $obj = json_decode($retour);
  if ($obj->status === "success") {
    return $obj->data->token;
  }
  return "";
}



function GetApplicationWithName($token, $name)
{
  $data = array("token" => $token);
  $retour = curl_post("http://localhost/api/applications", $data);
  if ($retour === FALSE) {
    return null;
  }
  $obj = json_decode($retour);
  if ($obj->status !== "success")
    return null;
  foreach ($obj->data as $application) {
    if ($application->name === $name) {
      return $application;
    }
  }
  return null;
}


function GetUserWithName($token, $username)
{
  $data = array("token" => $token);
  $retour = curl_post("http://localhost/api/users", $data);
  if ($retour === FALSE) {
    return null;
  }
  $obj = json_decode($retour);
  if ($obj->status !== "success")
    return null;
  foreach ($obj->data as $user) {
    if ($user->username === $username) {
      return $user;
    }
  }
  return null;
}


function AddApplicationUser($token, $appid, $userid)
{
  $data = array("token" => $token, "application_id" => $appid, "user_id" => $userid);
  $retour = curl_post("http://localhost/api/add_application_user", $data);
  if ($retour === FALSE) {
    return false;
  }
  $obj = json_decode($retour);
  return $obj->status === "success";
}




$token = AuthentifyWithMaintKey();
if ($token === "") {
  echo "Unable to login to API" . PHP_EOL;
}

echo "Getting application ID for application StatExplorer" . PHP_EOL;
$application = GetApplicationWithName($token, "StatExplorer");
if ($application === null) {
  echo "Failed to retrieve application with name StatExplorer" . PHP_EOL;
  return;
}
echo "Got application ID " . $application->application_id . PHP_EOL;

echo "Getting User ID for user admin" . PHP_EOL;
$user = GetUserWithName($token, "admin");
if ($user === null) {
  echo "Failed to retrieve user with name admin" . PHP_EOL;
  return;
}
echo "Got User ID " . $user->user_id . PHP_EOL;


echo "Adding application access to user" . PHP_EOL;
$success = AddApplicationUser($token, $application->application_id, $user->user_id);
if ($success === false) {
  echo "Failed to add application access to user" . PHP_EOL;
  return;
}
echo "Successfully added application access for admin user" . PHP_EOL;
