#!/bin/bash
PRODUCTNAME="statexplorer"
TMPDIR="/tmp/statexplorer"
INSTALLPATH="/usr/share/ombutel/www"
IPCDIR="/etc/ipconnect"
OLDVERSION=-1
NEWVERSION=-1
MAJORVERSION=3


mkdir -p "$TMPDIR"
mkdir -p "$IPCDIR"

if [ -e "$IPCDIR/$PRODUCTNAME.ver" ]
then
    OLDVERSION=$(cat "$IPCDIR/$PRODUCTNAME.ver" |cut -d"." -f2)
fi
NEWVERSION=$(head -n 1 "$INSTALLPATH/$PRODUCTNAME/version.txt" |cut -d"." -f2)
echo "-- Updating from $MAJORVERSION.$OLDVERSION to $MAJORVERSION.$NEWVERSION"

find "$INSTALLPATH/$PRODUCTNAME/api/scripts" -name '*.sh' -exec dos2unix {} 2> /dev/null \;

if [ ! -f "/etc/$PRODUCTNAME/Settings.php" ]
then
    echo "-- Creating settings"
    cp "$INSTALLPATH/$PRODUCTNAME/api/Settings_template.php" "/etc/$PRODUCTNAME/Settings.php"
fi

chmod +x "$INSTALLPATH/$PRODUCTNAME/InstallScripts/after_remove.sh"
chmod +x "$INSTALLPATH/$PRODUCTNAME/InstallScripts/after_update.sh"
chmod +x "$INSTALLPATH/$PRODUCTNAME/InstallScripts/before_remove.sh"
chmod +x "$INSTALLPATH/$PRODUCTNAME/InstallScripts/before_update.sh"
chmod +x "$INSTALLPATH/$PRODUCTNAME/InstallScripts/migrate_db.sh"

#On va faire une boucle à partir de "ancienne version + 1" jusqu'a la derniere version incluse
i=$(($OLDVERSION+1))
if [ $OLDVERSION -eq $NEWVERSION ]
then
	i=$OLDVERSION;
	echo "-- Updating same version but different revision, reexecuting patch of $i"
fi

while [ $i -le $NEWVERSION ]
do
  if [ -d "$INSTALLPATH/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i" ]
  then
    echo "-- Executing patch $MAJORVERSION.$i"
    find "$INSTALLPATH/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i" -name '*' -exec dos2unix {} 2> /dev/null \;
    bash "$INSTALLPATH/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i/update.sh"
  fi
  i=$(($i+1))
done

if [ -f /tmp/resetdb ]
then
  /bin/sh $INSTALLPATH/$PRODUCTNAME/api/scripts/resetdb.sh
  rm -f /tmp/resetdb
fi


echo "$MAJORVERSION.$NEWVERSION" > "$IPCDIR/$PRODUCTNAME.ver"
echo "-- Update finished"


# #### NE PAS RETIRER CE BLOC DES SCRIPTS DE MISE A JOUR
echo "-- Initializing startup script"
cat > $INSTALLPATH/$PRODUCTNAME/api/scripts/analyse.sh <<-EOF
#!/bin/bash

touch /var/log/statexplorer.log
echo \$\$ > /var/run/statexplorer.pid
echo "Service started with pid \$\$" >> /var/log/statexplorer.log

while [ -f /var/run/statexplorer.pid ]
do
  echo "Starting new analysis" >> /var/log/statexplorer.log
  if [ -f /etc/ipconnect/reset_stats ]
  then
    echo "Resetings data after update" >> /var/log/statexplorer.log
    /bin/bash $INSTALLPATH/$PRODUCTNAME/api/scripts/resetdb.sh
  fi
  nice -n 19 /usr/bin/php $INSTALLPATH/$PRODUCTNAME/api/scripts/queueanalyser/queueanalyser.php &>> /var/log/statexplorer.log
  nice -n 19 /usr/bin/php $INSTALLPATH/$PRODUCTNAME/api/scripts/celanalyser/celanalyser.php -a -w &>> /var/log/statexplorer.log
  sleep 20
done

echo "Service with pid $$ stopped" >> /var/log/statexplorer.log
EOF
# #### FIN DU BLOC


rm -rf "$TMPDIR"


systemctl restart statexplorer
exit